Swanson
=======

**Swanson** is a BDD test runner, **designed for Django**. It takes
specs in plain-text format, and runs them with the rest of your test suite.

* Docs: http://swanson.readthedocs.org/
* Source: https://github.com/nathforge/swanson
* PyPI: https://pypi.python.org/pypi/swanson
